import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

public class RecordTester {
	final static String USER = "root";
    final static String PASSWORD = "root";
    final static String MYSQL_STRING = "jdbc:mysql://localhost:8889/";
    final static String SQLITE_STRING = "jdbc:sqlite:";
    
	static Connection conn = null;
    static ResultSet rs = null;
    static Statement stmt = null;
	
    static String dbms;
    static String db;
    
	public static void main(String[] args)
    {
		// check arg length
		if (args.length != 7) 
			throw new RuntimeException("Expected 7 command line arguments. Got: " + args.length);
		
		dbms = args[0];
		db = args[1];
		String table_name = args[2];
		String type = args[3];
		String num_rows = args[4];
		String num_columns = args[5];
		String index_no_index = args[6];
		
		// argument checks
		if (!dbms.equals("mysql") && !dbms.equals("sqlite"))
			throw new RuntimeException("Expected mysql or sqlite. Got: " + dbms);
		if (!type.equals("INTEGER") 
				&& !type.substring(0, 4).equals("CHAR")
				&& !type.substring(0, 7).equals("VARCHAR"))
			throw new RuntimeException("Expected INTEGER, CHAR(n) or VARCHAR(n) Got: " + type);
		
		try {
        	connectToDatabase();
            
        	stmt.executeUpdate("DROP TABLE IF EXISTS " + table_name + ";");
        	System.out.println("Executed Drop Table Statement");  
        	
        	String createStatement = "CREATE TABLE " + table_name + "(";
        	for (int i = 0; i < Integer.parseInt(num_columns); i++) {
        		createStatement += "col" + (i + 1) + " " + type;
        		if (i != Integer.parseInt(num_columns) - 1)
        			createStatement += ",";
        	}
        	createStatement += ");";
        	
            stmt.executeUpdate(createStatement);
        	System.out.println("Executed Create Table Statment");  
            
        	if (dbms.toLowerCase().contentEquals("sqlite")) {
            	stmt.executeUpdate("DROP INDEX IF EXISTS col_index;");
                System.out.println("Executed Drop Index Statement");
        	}
            
            if (index_no_index.toLowerCase().equals("true")) {
            	stmt.executeUpdate("CREATE UNIQUE INDEX col_index ON " + table_name + "(col1);");
            	System.out.println("Executed Create Index Statement"); 
            }
            
            for (int r = 0; r < Integer.parseInt(num_rows); r++) {
                String insertStatement = "INSERT INTO " + table_name + " VALUES(";
            	for (int i = 0; i < Integer.parseInt(num_columns); i++) {
            		insertStatement += "\"" + (r + 1) + "\"";
            		if (i != Integer.parseInt(num_columns) - 1)
            			insertStatement += ",";
    	        }
            	insertStatement += ");";
                System.out.println("Executed Insert Statement (" + (r + 1) + ")"); 
            	stmt.executeUpdate(insertStatement);
	        }


        } 
        catch (SQLException ex) {
            // handle any errors
            System.out.println("SQLException: " + ex.getMessage());
            System.out.println("SQLState: " + ex.getSQLState());
            System.out.println("VendorError: " + ex.getErrorCode());
        } 
        finally {
        	finishUp();
        }
    }
	
	public static void connectToDatabase() throws SQLException {
		if (dbms.toLowerCase().equals("sqlite")) {
			conn = DriverManager.getConnection(SQLITE_STRING + db);
			System.out.println("Connection to SQLite has been established. Using database " + db); 
	        stmt = conn.createStatement();
		}
		else {
			conn = DriverManager.getConnection(MYSQL_STRING, USER, PASSWORD);
			System.out.println("Connection to MySQL has been established."); 
	        stmt = conn.createStatement();
	        
	        stmt.executeUpdate("DROP DATABASE IF EXISTS " + db + ";");
	        System.out.println("Executed Drop Database Statment");  
	        stmt.executeUpdate("CREATE DATABASE " + db + ";");
	        
	        conn = DriverManager.getConnection(MYSQL_STRING + db, USER, PASSWORD);
	        stmt = conn.createStatement();
	        System.out.println("Executed Create Database Statment, using Database " + db);  
	        
		}
	}
	
	public static void finishUp() {
		if (rs != null) {
            try {
                rs.close();
            } catch (SQLException sqlEx) { } // ignore
            rs = null;
        }
        if (stmt != null) {
            try {
                stmt.close();
            } catch (SQLException sqlEx) { } // ignore
            stmt = null;
        }
	}
}
